==> python-dateparser-1.0.0-2-any.pkg.tar.zst: usr/lib/python3.9/site-packages/dateparser/data/date_translation_data/nb.py <==
info = {
    "name": "nb",
    "date_order": "DMY",
    "january": [
        "januar",
        "jan"
    ],
    "february": [
        "februar",
        "feb"
    ],
    "march": [
        "mars",
        "mar"
    ],
    "april": [
        "april",
        "apr"
    ],
    "may": [
        "mai"
    ],
    "june": [
        "juni",
        "jun"
    ],
    "july": [
        "juli",
        "jul"
    ],
    "august": [
        "august",
        "aug"
    ],
    "september": [
        "september",
        "sep"
    ],
    "october": [
        "oktober",
        "okt"
    ],
    "november": [
        "november",
        "nov"
    ],
    "december": [
        "desember",
        "des"
    ],
    "monday": [
        "mandag",
        "man"
    ],
    "tuesday": [
        "tirsdag",
        "tir"
    ],
    "wednesday": [
        "onsdag",
        "ons"
    ],
    "thursday": [
        "torsdag",
        "tor"
    ],
    "friday": [
        "fredag",
        "fre"
    ],
    "saturday": [
        "lørdag",
        "lør"
    ],
    "sunday": [
        "søndag",
        "søn"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "år"
    ],
    "month": [
        "måned",
        "mnd",
        "md"
    ],
    "week": [
        "uke",
        "u",
        "uker"
    ],
    "day": [
        "dag",
        "d",
        "dager"
    ],
    "hour": [
        "time",
        "t",
        "timer"
    ],
    "minute": [
        "minutt",
        "min",
        "m"
    ],
    "second": [
        "sekund",
        "sek",
        "s"
    ],
    "relative-type": {
        "1 year ago": [
            "i fjor"
        ],
        "0 year ago": [
            "i år"
        ],
        "in 1 year": [
            "neste år"
        ],
        "1 month ago": [
            "forrige måned",
            "forrige md"
        ],
        "0 month ago": [
            "denne måneden",
            "denne md"
        ],
        "in 1 month": [
            "neste måned",
            "neste md"
        ],
        "1 week ago": [
            "forrige uke"
        ],
        "0 week ago": [
            "denne uken"
        ],
        "in 1 week": [
            "neste uke"
        ],
        "1 day ago": [
            "i går"
        ],
        "0 day ago": [
            "i dag"
        ],
        "in 1 day": [
            "i morgen"
        ],
        "0 hour ago": [
            "denne timen"
        ],
        "0 minute ago": [
            "dette minuttet"
        ],
        "0 second ago": [
            "nå"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "om (\\d+) år"
        ],
        "\\1 year ago": [
            "for (\\d+) år siden",
            "–(\\d+) år"
        ],
        "in \\1 month": [
            "om (\\d+) måned",
            "om (\\d+) måneder",
            "om (\\d+) md"
        ],
        "\\1 month ago": [
            "for (\\d+) måned siden",
            "for (\\d+) måneder siden",
            "for (\\d+) md siden"
        ],
        "in \\1 week": [
            "om (\\d+) uke",
            "om (\\d+) uker",
            "om (\\d+) u"
        ],
        "\\1 week ago": [
            "for (\\d+) uke siden",
            "for (\\d+) uker siden",
            "for (\\d+) u siden"
        ],
        "in \\1 day": [
            "om (\\d+) døgn",
            "om (\\d+) d"
        ],
        "\\1 day ago": [
            "for (\\d+) døgn siden",
            "for (\\d+) d siden",
            "for (\\d+) dager siden"
        ],
        "in \\1 hour": [
            "om (\\d+) time",
            "om (\\d+) timer",
            "om (\\d+) t"
        ],
        "\\1 hour ago": [
            "for (\\d+) time siden",
            "for (\\d+) timer siden",
            "for (\\d+) t siden"
        ],
        "in \\1 minute": [
            "om (\\d+) minutt",
            "om (\\d+) minutter",
            "om (\\d+) min"
        ],
        "\\1 minute ago": [
            "for (\\d+) minutt siden",
            "for (\\d+) minutter siden",
            "for (\\d+) min siden"
        ],
        "in \\1 second": [
            "om (\\d+) sekund",
            "om (\\d+) sekunder",
            "om (\\d+) sek"
        ],
        "\\1 second ago": [
            "for (\\d+) sekund siden",
            "for (\\d+) sekunder siden",
            "for (\\d+) sek siden"
        ]
    },
    "locale_specific": {
        "nb-SJ": {
            "name": "nb-SJ"
        }
    },
    "ago": [
        "siden"
    ],
    "in": [
        "om"
    ],
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}

==> python-dateparser-1.1.0-2-any.pkg.tar.zst: usr/lib/python3.10/site-packages/dateparser/data/date_translation_data/nb.py <==
info = {
    "name": "nb",
    "date_order": "DMY",
    "january": [
        "jan",
        "januar"
    ],
    "february": [
        "feb",
        "februar"
    ],
    "march": [
        "mar",
        "mars"
    ],
    "april": [
        "apr",
        "april"
    ],
    "may": [
        "mai"
    ],
    "june": [
        "jun",
        "juni"
    ],
    "july": [
        "jul",
        "juli"
    ],
    "august": [
        "aug",
        "august"
    ],
    "september": [
        "sep",
        "september"
    ],
    "october": [
        "okt",
        "oktober"
    ],
    "november": [
        "nov",
        "november"
    ],
    "december": [
        "des",
        "desember"
    ],
    "monday": [
        "man",
        "mandag"
    ],
    "tuesday": [
        "tir",
        "tirsdag"
    ],
    "wednesday": [
        "ons",
        "onsdag"
    ],
    "thursday": [
        "tor",
        "torsdag"
    ],
    "friday": [
        "fre",
        "fredag"
    ],
    "saturday": [
        "lør",
        "lørdag"
    ],
    "sunday": [
        "søn",
        "søndag"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "år"
    ],
    "month": [
        "md",
        "mnd",
        "måned"
    ],
    "week": [
        "u",
        "uke",
        "uker"
    ],
    "day": [
        "d",
        "dag",
        "dager"
    ],
    "hour": [
        "t",
        "time",
        "timer"
    ],
    "minute": [
        "m",
        "min",
        "minutt"
    ],
    "second": [
        "s",
        "sek",
        "sekund"
    ],
    "relative-type": {
        "0 day ago": [
            "i dag"
        ],
        "0 hour ago": [
            "denne timen"
        ],
        "0 minute ago": [
            "dette minuttet"
        ],
        "0 month ago": [
            "denne md",
            "denne måneden"
        ],
        "0 second ago": [
            "nå"
        ],
        "0 week ago": [
            "denne uken"
        ],
        "0 year ago": [
            "i år"
        ],
        "1 day ago": [
            "i går"
        ],
        "1 month ago": [
            "forrige md",
            "forrige måned"
        ],
        "1 week ago": [
            "forrige uke"
        ],
        "1 year ago": [
            "i fjor"
        ],
        "in 1 day": [
            "i morgen"
        ],
        "in 1 month": [
            "neste md",
            "neste måned"
        ],
        "in 1 week": [
            "neste uke"
        ],
        "in 1 year": [
            "neste år"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "for (\\d+) d siden",
            "for (\\d+) døgn siden",
            "for (\\d+) dager siden"
        ],
        "\\1 hour ago": [
            "for (\\d+) t siden",
            "for (\\d+) time siden",
            "for (\\d+) timer siden"
        ],
        "\\1 minute ago": [
            "for (\\d+) min siden",
            "for (\\d+) minutt siden",
            "for (\\d+) minutter siden"
        ],
        "\\1 month ago": [
            "for (\\d+) md siden",
            "for (\\d+) måned siden",
            "for (\\d+) måneder siden"
        ],
        "\\1 second ago": [
            "for (\\d+) sek siden",
            "for (\\d+) sekund siden",
            "for (\\d+) sekunder siden"
        ],
        "\\1 week ago": [
            "for (\\d+) u siden",
            "for (\\d+) uke siden",
            "for (\\d+) uker siden"
        ],
        "\\1 year ago": [
            "for (\\d+) år siden",
            "–(\\d+) år"
        ],
        "in \\1 day": [
            "om (\\d+) d",
            "om (\\d+) døgn"
        ],
        "in \\1 hour": [
            "om (\\d+) t",
            "om (\\d+) time",
            "om (\\d+) timer"
        ],
        "in \\1 minute": [
            "om (\\d+) min",
            "om (\\d+) minutt",
            "om (\\d+) minutter"
        ],
        "in \\1 month": [
            "om (\\d+) md",
            "om (\\d+) måned",
            "om (\\d+) måneder"
        ],
        "in \\1 second": [
            "om (\\d+) sek",
            "om (\\d+) sekund",
            "om (\\d+) sekunder"
        ],
        "in \\1 week": [
            "om (\\d+) u",
            "om (\\d+) uke",
            "om (\\d+) uker"
        ],
        "in \\1 year": [
            "om (\\d+) år"
        ]
    },
    "locale_specific": {
        "nb-SJ": {
            "name": "nb-SJ"
        }
    },
    "ago": [
        "siden"
    ],
    "in": [
        "om"
    ],
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
